@@ -40,20 +40,16 @@ power.NTIDFDA <- function(alpha=0.05, theta1, theta2, theta0, CV, n,
     # we assume n=ntotal
     # for unbalanced designs we divide the ns by ourself
     # in such a way that we have only small imbalance
-    ni <- round(n/seqs,0)
-    nv <- rep.int(ni, times=seqs-1)
-    nv <- c(nv, n-sum(nv))
-    if (nv[length(nv)]!=ni){
-      message("Unbalanced design. n(i)=", paste(nv, collapse="/"),
-              " assumed.")
-    } 
+    nv <- nvec(n=n, grps=seqs)
+    if (nv[1]!=nv[length(nv)]){
+      message("Unbalanced design. n(i)=", paste(nv, collapse="/"), " assumed.")
+    }
     C3 <- sum(1/nv)/seqs^2
     n  <- sum(nv)
   } else {
     # we assume n = vector of n's in sequences
     # check length
     if (length(n)!=seqs) stop("n must be a vector of length=",seqs,"!", call.=FALSE)
-    
     C3 <- sum(1/n)/seqs^2
     n  <- sum(n)
   }
